| Title: | Rcpp Interface to Hyper-Dual Numbers |
|---|---|
| Description: | Hyper-Dual Numbers permit the exact calculation of second derivatives which is both free of truncation and subtractive cancellation. Hyper-Dual numbers were introduced Jeffrey Fike and Juan Alonson, and this package uses a header-only C++ implementation by Fike and released under the MIT license. Accurate 2nd derivatives computation. |
| Authors: | Dirk Eddelbuettel, Ravi Varadhan and Tim Triche |
| Maintainer: | Dirk Eddelbuettel <[email protected]> |
| License: | GPL (>= 2) |
| Version: | 0.0.1 |
| Built: | 2026-05-27 09:14:15 UTC |
| Source: | https://github.com/eddelbuettel/rcpphyperdual |
This package provides an interface to Hyper-Dual Numbers by Jeffrey Fike and Juan Alonson.
To be done.
Dirk Eddelbuettel
Maintainer: Dirk Eddelbuettel <[email protected]>
addHD( c(1,2,0,0), c(2,-1,0,1))addHD( c(1,2,0,0), c(2,-1,0,1))
This function adds two hyper-dual numbers
addHD(x, y, verbose = FALSE)addHD(x, y, verbose = FALSE)
x |
A vector of length four containg a hyper-dual number |
y |
A vector of length four containg a hyper-dual number |
verbose |
A boolean variable with default ‘false’ indicating if verbose operation is desired. |
A vector of length four containing the resulting hyper-dual number.
Dirk Eddelbuettel
addHD( c(1,0,0,1), c(2,1,0,-1) )addHD( c(1,0,0,1), c(2,1,0,-1) )